<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru" sourcelanguage="en">
  <context>
    <name>CmdPointsConvert</name>
    <message>
      <location filename="../../Command.cpp" line="189"/>
      <source>Points</source>
      <translation>Точки</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="190"/>
      <source>Convert to points...</source>
      <translation>Преобразовать в точки...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="191"/>
      <location filename="../../Command.cpp" line="193"/>
      <source>Convert to points</source>
      <translation>Преобразовать в точки</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsExport</name>
    <message>
      <location filename="../../Command.cpp" line="112"/>
      <source>Points</source>
      <translation>Точки</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="113"/>
      <source>Export points...</source>
      <translation>Экспорт точек...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="114"/>
      <location filename="../../Command.cpp" line="116"/>
      <source>Exports a point cloud</source>
      <translation>Экспорт облака точек</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsImport</name>
    <message>
      <location filename="../../Command.cpp" line="67"/>
      <source>Points</source>
      <translation>Точки</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="68"/>
      <source>Import points...</source>
      <translation>Импорт точек...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="69"/>
      <location filename="../../Command.cpp" line="71"/>
      <source>Imports a point cloud</source>
      <translation>Импорт облака точек</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsMerge</name>
    <message>
      <location filename="../../Command.cpp" line="310"/>
      <source>Points</source>
      <translation>Точки</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="311"/>
      <source>Merge point clouds</source>
      <translation>Слияние облаков точек</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="312"/>
      <location filename="../../Command.cpp" line="314"/>
      <source>Merge several point clouds into one</source>
      <translation>Объединить несколько облаков точек в одно</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsPolyCut</name>
    <message>
      <location filename="../../Command.cpp" line="265"/>
      <source>Points</source>
      <translation>Точки</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="266"/>
      <source>Cut point cloud</source>
      <translation>Вырезать облако точек</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="267"/>
      <location filename="../../Command.cpp" line="269"/>
      <source>Cuts a point cloud with a picked polygon</source>
      <translation>Вырезать облако точек, ограниченное отмеченным полигоном</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsStructure</name>
    <message>
      <location filename="../../Command.cpp" line="371"/>
      <source>Points</source>
      <translation>Точки</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="372"/>
      <source>Structured point cloud</source>
      <translation>Облако структурированных точек</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="373"/>
      <location filename="../../Command.cpp" line="375"/>
      <source>Convert points to structured point cloud</source>
      <translation>Преобразование точек в облако структурированных точек</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsTransform</name>
    <message>
      <location filename="../../Command.cpp" line="152"/>
      <source>Points</source>
      <translation>Точки</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="153"/>
      <source>Transform Points</source>
      <translation>Преобразование точек</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="154"/>
      <location filename="../../Command.cpp" line="156"/>
      <source>Test to transform a point cloud</source>
      <translation>Тест для преобразования облака точек</translation>
    </message>
  </context>
  <context>
    <name>Command</name>
    <message>
      <location filename="../../Command.cpp" line="88"/>
      <source>Import points</source>
      <translation>Импортировать точки</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="168"/>
      <source>Transform points</source>
      <translation>Преобразовать точки</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="214"/>
      <source>Convert to points</source>
      <translation>Преобразовать в точки</translation>
    </message>
    <message>
      <location filename="../../ViewProvider.cpp" line="456"/>
      <location filename="../../ViewProvider.cpp" line="615"/>
      <source>Cut points</source>
      <translation>Вырезать точки</translation>
    </message>
  </context>
  <context>
    <name>PointsGui::DlgPointsRead</name>
    <message>
      <location filename="../../DlgPointsRead.ui" line="14"/>
      <source>ASCII points import</source>
      <translation>Импорт точек ASCII</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="34"/>
      <source>Template:</source>
      <translation>Шаблон:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="46"/>
      <source>Special lines</source>
      <translation>Специальные линии</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="58"/>
      <source>First line:</source>
      <translation>Первая линия:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="70"/>
      <source>Ignore</source>
      <translation>Игнорировать</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="80"/>
      <source>Number of points</source>
      <translation>Количество точек</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="101"/>
      <source>Cluster by lines starting with:</source>
      <translation>Кластер по линии, начиная с:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="111"/>
      <source>Ignore lines starting with:</source>
      <translation>Игнорировать строки, начинающиеся с:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="126"/>
      <source>Point format</source>
      <translation>Формат точек</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="146"/>
      <source>Number separator:</source>
      <translation>Числовой разделитель:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="167"/>
      <source>\t</source>
      <translation>\t</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="172"/>
      <source>\w</source>
      <translation>\w</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="180"/>
      <source>Points format:</source>
      <translation>Формат точек:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="188"/>
      <source>X,Y,Z</source>
      <translation>X, Y, Z</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="193"/>
      <source>X,Y</source>
      <translation>X, Y</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="201"/>
      <location filename="../../DlgPointsRead.ui" line="237"/>
      <location filename="../../DlgPointsRead.ui" line="273"/>
      <source>Next block:</source>
      <translation>Следующий блок:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="209"/>
      <location filename="../../DlgPointsRead.ui" line="245"/>
      <location filename="../../DlgPointsRead.ui" line="281"/>
      <source>none</source>
      <translation>Отсутствует</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="214"/>
      <location filename="../../DlgPointsRead.ui" line="250"/>
      <location filename="../../DlgPointsRead.ui" line="286"/>
      <source>I,J,K (normal vector)</source>
      <translation>I, J, K (вектор нормали)</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="219"/>
      <location filename="../../DlgPointsRead.ui" line="255"/>
      <location filename="../../DlgPointsRead.ui" line="291"/>
      <source>I,K (normal vector 2D)</source>
      <translation>I, K (вектор нормали 2D)</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="224"/>
      <location filename="../../DlgPointsRead.ui" line="260"/>
      <location filename="../../DlgPointsRead.ui" line="296"/>
      <source>R,G,B (color)</source>
      <translation>R, G, B (цвет)</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="229"/>
      <location filename="../../DlgPointsRead.ui" line="265"/>
      <location filename="../../DlgPointsRead.ui" line="301"/>
      <source>I (Gray value)</source>
      <translation>I (значение серого)</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="314"/>
      <source>Preview</source>
      <translation>Предварительный просмотр</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="341"/>
      <source>Number of previewed lines:</source>
      <translation>Количество предварительно просматриваемых строк:</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../Command.cpp" line="81"/>
      <location filename="../../Command.cpp" line="129"/>
      <source>Point formats</source>
      <translation>Форматы точек</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="81"/>
      <location filename="../../Command.cpp" line="129"/>
      <source>All Files</source>
      <translation>Все файлы</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="208"/>
      <source>Distance</source>
      <translation>Расстояние</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="209"/>
      <source>Enter maximum distance:</source>
      <translation>Введите максимальное расстояние:</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="34"/>
      <source>Points tools</source>
      <translation>Инструменты для точек</translation>
    </message>
    <message>
      <location filename="../../Workbench.cpp" line="35"/>
      <source>&amp;Points</source>
      <translation>&amp;Точки</translation>
    </message>
  </context>
</TS>
